<?php
/**
 * Template Name: Gallery Template                                            
 * The template for displaying gallery page.
 *
 * @link https://codex.wordpress.org/Template_Hierarchy
 *
 * @package Theme Palace
 * @subpackage Elead Pro
 * @since Elead Pro 1.0
 */

get_header(); 
$options = elead_pro_get_theme_options(); 
$gallery_title      = ! empty( $options['gallery_template_title'] ) ? $options['gallery_template_title'] : '';
$gallery_subtitle  = ! empty( $options['gallery_template_subtitle'] ) ? $options['gallery_template_subtitle'] : '';
?>
<section id="masonry-gallery" class="page-section">    
    <div class="wrapper">
        <header class="entry-header align-center">
            <?php if ( ! empty( $gallery_title ) ) : ?>
                <h2 class="entry-title"><?php echo esc_html( $gallery_title ); ?></h2>
            <?php endif; 
            if ( ! empty( $gallery_subtitle ) ) : ?>
                <p class="entry-title-desc"><?php echo esc_html( $gallery_subtitle ); ?></p>
            <?php endif; ?>
        </header>
        <div class="entry-content gallery-popup">
            <?php 
            if( 'category' == $options['gallery_template_type'] ) :
                $categories_id = ! empty( $options['gallery_template_category'] ) ? $options['gallery_template_category'] : ''; 
                $categories_id = ! empty( $categories_id ) ? $categories_id : array();     
                ?>
                <nav class="portfolio-filter">
                    <ul class="nav-tabs clear">
                        <li class="active"><a href="#" data-filter="*"><?php esc_html_e( 'All', 'elead-pro' ); ?></a></li>
                        <?php foreach ( $categories_id as $key => $category_id ) {
                            $category_object = get_category( $category_id );
                            echo '<li><a href="#" data-filter=".'. esc_attr( $category_object->slug ) .'">'. esc_html( $category_object->name ) .'</a></li>';
                        } ?>
                    </ul><!-- .nav-tabs -->
                </nav>
                <?php  
                $gallery_args = array(
                    'post_type'      => 'post',
                    'category__in'   => $categories_id,
                    'posts_per_page' => -1,
                );
                $i = 1;
                $posts = get_posts( $gallery_args );
                ?>

                <div class="grid">
                    <?php foreach ( $posts as $post ) : 
                        $post_id = $post->ID;
                        if ( has_post_thumbnail( $post_id ) ) {
                            if ( $i <= 2 ) :
                                $img_array = wp_get_attachment_image_src( get_post_thumbnail_id( $post_id ), 'medium_large' );
                                $img_array_lg = wp_get_attachment_image_src( get_post_thumbnail_id( $post_id ), 'full' );
                            else :
                                $img_array = wp_get_attachment_image_src( get_post_thumbnail_id( $post_id ), 'elead-pro-medium' );
                                $img_array_lg = wp_get_attachment_image_src( get_post_thumbnail_id( $post_id ), 'full' );
                            endif;
                        } else {
                            $img_array[0] = get_template_directory_uri().'/assets/uploads/no-featured-image-500x500.jpg';
                            $img_array_lg[0] = '';
                        }

                        $post_title = get_the_title( $post_id );
                        $post_url = get_the_permalink( $post_id ); 
                        $post_categories = get_the_category( $post_id );

                        $post_category_list = '';
                        foreach ( $post_categories as $post_category ) {
                            $post_category_list .= $post_category->slug . ' ';
                        }
                        ?>
                        <div class="grid-item <?php echo esc_attr( $post_category_list ); ?>">
                            <figure class="featured-image" style="background-image: url('<?php echo esc_url( $img_array[0] ); ?>');">
                                <div class="gallery-hover">
                                    <span class="gallery-item-title"><a href="<?php echo esc_url( $post_url ); ?>"><?php echo esc_html( $post_title ); ?></a></span>
                                    <span>
                                        <?php if ( ! empty( $img_array_lg[0] ) ) : ?>
                                            <a href="<?php echo esc_url( $img_array_lg[0] ); ?>" class="popup"><i class="fa fa-camera"></i></a>
                                        <?php endif; ?>
                                        <a href="<?php echo esc_url( $post_url ); ?>"><i class="fa fa-link"></i></a>
                                    </span>
                                </div><!-- .gallery-hover -->
                            </figure>
                        </div><!-- .grid-item -->
                    <?php $i++; 
                    endforeach; 
                    wp_reset_postdata(); ?>
                </div><!-- .grid -->
            <?php
            else : 
                $content_custom_value = $options['gallery_template_custom'];
                if ( ! empty( $content_custom_value ) ) {
                    echo '<div class="grid">';
                    $i = 1;
                    $gallery_multiple_images = ( array ) $options['gallery_template_custom'];
                    foreach ( $gallery_multiple_images as $gallery_multiple_image ) : ?>
                        <div class="grid-item">
                            <figure class="featured-image" style="background-image: url('<?php echo esc_url( $gallery_multiple_image ); ?>');">
                                <div class="gallery-hover gallery-hover-icon">
                                    <span>
                                        <a href="<?php echo esc_url( $gallery_multiple_image ); ?>" class="popup"><i class="fa fa-camera"></i></a>
                                    </span>
                                </div><!-- .gallery-hover -->
                            </figure>
                        </div><!-- .grid-item -->
                    <?php endforeach;
                    echo '</div><!-- .grid -->';
                }
            endif; ?>
        </div><!-- .entry-content -->
    </div><!-- .wrapper -->
</section><!-- #contact-form -->
<?php
get_footer();