<?php
/**
 * Elead Pro functions and definitions.
 *
 * @link https://developer.wordpress.org/themes/basics/theme-functions/
 *
 * @package Theme Palace
 * @subpackage Elead Pro
 * @since Elead Pro 1.0
 */

if ( ! function_exists( 'elead_pro_setup' ) ) :
	/**
	 * Sets up theme defaults and registers support for various WordPress features.
	 *
	 * Note that this function is hooked into the after_setup_theme hook, which
	 * runs before the init hook. The init hook is too late for some features, such
	 * as indicating support for post thumbnails.
	 */
	function elead_pro_setup() {
		/*
		 * Make theme available for translation.
		 * Translations can be filed in the /languages/ directory.
		 * If you're building a theme based on Theme Palace, use a find and replace
		 * to change 'elead-pro' to the name of your theme in all the template files.
		 */
		load_theme_textdomain( 'elead-pro', get_template_directory() . '/languages' );

		// Add default posts and comments RSS feed links to head.
		add_theme_support( 'automatic-feed-links' );

		/*
		 * Let WordPress manage the document title.
		 * By adding theme support, we declare that this theme does not use a
		 * hard-coded <title> tag in the document head, and expect WordPress to
		 * provide it for us.
		 */
		add_theme_support( 'title-tag' );

		/*
		 * Enable support for Post Thumbnails on posts and pages.
		 *
		 * @link https://developer.wordpress.org/themes/functionality/featured-images-post-thumbnails/
		 */
		add_theme_support( 'post-thumbnails' );
		set_post_thumbnail_size( 360, 300, true );
		add_image_size( 'elead-pro-medium', 400, 400, true );
		add_image_size( 'elead-pro-latest-news', 650, 310, true );

		// This theme uses wp_nav_menu() in one location.
		register_nav_menus( array(
			'primary' => esc_html__( 'Primary', 'elead-pro' ),
		) );

		/*
		 * Switch default core markup for search form, comment form, and comments
		 * to output valid HTML5.
		 */
		add_theme_support( 'html5', array(
			'comment-form',
			'comment-list',
			'gallery',
			'caption',
		) );

		// Set up the WordPress core custom background feature.
		add_theme_support( 'custom-background', apply_filters( 'elead_pro_custom_background_args', array(
			'default-color' => 'ffffff',
			'default-image' => '',
		) ) );

		// This setup supports logo, site-title & site-description
		add_theme_support( 'custom-logo', array(
			'height'      => 70,
			'width'       => 120,
			'flex-height' => true,
			'flex-width'  => true,
			'header-text' => array( 'site-title', 'site-description' ),
		) );

		/*
		 * This theme styles the visual editor to resemble the theme style,
		 * specifically font, colors, icons, and column width.
		 */
		$min = defined( 'SCRIPT_DEBUG' ) && SCRIPT_DEBUG ? '' : '.min';
		add_editor_style( array( 'assets/css/editor-style' .$min. '.css' ) );

		// Indicate widget sidebars can use selective refresh in the Customizer.
		add_theme_support( 'customize-selective-refresh-widgets' );

		// Add WooCommerce support
		add_theme_support( 'woocommerce' );

		if ( class_exists( 'WooCommerce' ) ) {
	    	global $woocommerce;
	
	    	if( version_compare( $woocommerce->version, '3.0.0', ">=" ) ) {
	      		add_theme_support( 'wc-product-gallery-zoom' );
				add_theme_support( 'wc-product-gallery-lightbox' );
				add_theme_support( 'wc-product-gallery-slider' );
			}
	  	}

		if ( is_admin() ) {
			/**
			 * Load updater file
			 */
			require get_template_directory() . '/updater/theme-updater.php';
		}

		// Gutenberg support
		add_theme_support( 'editor-color-palette', array(
	       	array(
				'name' => esc_html__( 'Red', 'elead-pro' ),
				'slug' => 'red',
				'color' => '#c1331b',
	       	),
	       	array(
	           	'name' => esc_html__( 'Black', 'elead-pro' ),
	           	'slug' => 'black',
	           	'color' => '#2e2624',
	       	),
	       	array(
	           	'name' => esc_html__( 'Grey', 'elead-pro' ),
	           	'slug' => 'grey',
	           	'color' => '#bcbfd0',
	       	),
	   	));

		add_theme_support( 'align-wide' );
		add_theme_support( 'editor-font-sizes', array(
		   	array(
		       	'name' => esc_html__( 'small', 'elead-pro' ),
		       	'shortName' => esc_html__( 'S', 'elead-pro' ),
		       	'size' => 12,
		       	'slug' => 'small'
		   	),
		   	array(
		       	'name' => esc_html__( 'regular', 'elead-pro' ),
		       	'shortName' => esc_html__( 'M', 'elead-pro' ),
		       	'size' => 16,
		       	'slug' => 'regular'
		   	),
		   	array(
		       	'name' => esc_html__( 'larger', 'elead-pro' ),
		       	'shortName' => esc_html__( 'L', 'elead-pro' ),
		       	'size' => 36,
		       	'slug' => 'larger'
		   	),
		   	array(
		       	'name' => esc_html__( 'huge', 'elead-pro' ),
		       	'shortName' => esc_html__( 'XL', 'elead-pro' ),
		       	'size' => 48,
		       	'slug' => 'huge'
		   	)
		));
		add_theme_support('editor-styles');
		add_theme_support( 'wp-block-styles' );
	}
endif;
add_action( 'after_setup_theme', 'elead_pro_setup' );

/**
 * Set the content width in pixels, based on the theme's design and stylesheet.
 *
 * Priority 0 to make it available to lower priority callbacks.
 *
 * @global int $content_width
 */
function elead_pro_content_width() {
	$GLOBALS['content_width'] = apply_filters( 'elead_pro_content_width', 640 );
}
add_action( 'after_setup_theme', 'elead_pro_content_width', 0 );

if ( ! function_exists( 'elead_pro_fonts_url' ) ) :
/**
 * Register Google fonts
 *
 * @return string Google fonts URL for the theme.
 */
function elead_pro_fonts_url() {
	$fonts_url = '';
	$fonts     = array();
	$subsets   = 'latin,latin-ext';

	// body fonts

	/* translators: If there are characters in your language that are not supported by Oxygen, translate this to 'off'. Do not translate into your own language. */
	if ( 'off' !== _x( 'on', 'Oxygen font: on or off', 'elead-pro' ) ) {
		$fonts[] = 'Oxygen:300,400,700';
	}

	/* translators: If there are characters in your language that are not supported by |News Cycle, translate this to 'off'. Do not translate into your own language. */
	if ( 'off' !== _x( 'on', 'News Cycle font: on or off', 'elead-pro' ) ) {
		$fonts[] = 'News Cycle';
	}

	/* translators: If there are characters in your language that are not supported by Pontano Sans, translate this to 'off'. Do not translate into your own language. */
	if ( 'off' !== _x( 'on', 'Pontano Sans font: on or off', 'elead-pro' ) ) {
		$fonts[] = 'Pontano Sans';
	}

	/* translators: If there are characters in your language that are not supported by Gudea, translate this to 'off'. Do not translate into your own language. */
	if ( 'off' !== _x( 'on', 'Gudea font: on or off', 'elead-pro' ) ) {
		$fonts[] = 'Gudea';
	}

	/* translators: If there are characters in your language that are not supported by Quattrocento, translate this to 'off'. Do not translate into your own language. */
	if ( 'off' !== _x( 'on', 'Quattrocento font: on or off', 'elead-pro' ) ) {
		$fonts[] = 'Quattrocento';
	}

	/* translators: If there are characters in your language that are not supported by Khand, translate this to 'off'. Do not translate into your own language. */
	if ( 'off' !== _x( 'on', 'Khand font: on or off', 'elead-pro' ) ) {
		$fonts[] = 'Khand';
	}	
	
	// header fonts

	/* translators: If there are characters in your language that are not supported by Rajdhani, translate this to 'off'. Do not translate into your own language. */
	if ( 'off' !== _x( 'on', 'Rajdhani font: on or off', 'elead-pro' ) ) {
		$fonts[] = 'Rajdhani';
	}

	/* translators: If there are characters in your language that are not supported by Cherry Swash, translate this to 'off'. Do not translate into your own language. */
	if ( 'off' !== _x( 'on', 'Cherry Swash font: on or off', 'elead-pro' ) ) {
		$fonts[] = 'Cherry Swash';
	}

	/* translators: If there are characters in your language that are not supported by Philosopher, translate this to 'off'. Do not translate into your own language. */
	if ( 'off' !== _x( 'on', 'Philosopher font: on or off', 'elead-pro' ) ) {
		$fonts[] = 'Philosopher';
	}

	/* translators: If there are characters in your language that are not supported by Slabo 27px, translate this to 'off'. Do not translate into your own language. */
	if ( 'off' !== _x( 'on', 'Slabo 27px font: on or off', 'elead-pro' ) ) {
		$fonts[] = 'Slabo 27px';
	}

	/* translators: If there are characters in your language that are not supported by Dosis, translate this to 'off'. Do not translate into your own language. */
	if ( 'off' !== _x( 'on', 'Dosis font: on or off', 'elead-pro' ) ) {
		$fonts[] = 'Dosis';
	}

	/* translators: If there are characters in your language that are not supported by Playfair Display, translate this to 'off'. Do not translate into your own language. */
	if ( 'off' !== _x( 'on', 'Playfair Display font: on or off', 'elead-pro' ) ) {
		$fonts[] = 'Playfair Display:400,700,900';
	}
	
	/* translators: If there are characters in your language that are not supported by Raleway, translate this to 'off'. Do not translate into your own language. */
	if ( 'off' !== _x( 'on', 'Raleway font: on or off', 'elead-pro' ) ) {
		$fonts[] = 'Raleway:300,400,500';
	}
	
	if ( $fonts ) {
		$fonts_url = add_query_arg( array(
			'family' => urlencode( implode( '|', $fonts ) ),
			'subset' => urlencode( $subsets ),
		), 'https://fonts.googleapis.com/css' );
	}

	return $fonts_url;
}
endif;

/**
 * Enqueue scripts and styles.
 */
function elead_pro_scripts() {

	$options = elead_pro_get_theme_options();
	// Add custom fonts, used in the main stylesheet.
	$min = defined( 'SCRIPT_DEBUG' ) && SCRIPT_DEBUG ? '' : '.min';
	wp_enqueue_style( 'elead-pro-fonts', elead_pro_fonts_url(), array(), null );
	
	wp_enqueue_style( 'fontawesome', get_template_directory_uri() . '/assets/plugins/css/font-awesome' .$min. '.css', array(), '4.6.3' );

	wp_enqueue_style( 'slick', get_template_directory_uri() . '/assets/plugins/css/slick' .$min. '.css', array(), '1.6.0' );
	
	wp_enqueue_style( 'slick-theme', get_template_directory_uri() . '/assets/plugins/css/slick-theme' .$min. '.css', array(), '1.6.0' );
	
	wp_enqueue_style( 'magnific-popup', get_template_directory_uri() . '/assets/plugins/css/magnific-popup' .$min. '.css', array(), '' );

	wp_enqueue_style( 'elead-pro-blocks', get_template_directory_uri() . '/assets/css/blocks' .$min. '.css', array(), '' );

	wp_enqueue_style( 'elead-pro-style', get_stylesheet_uri() );

	$theme_color = ! empty( $options['theme_color'] ) ? $options['theme_color'] : 'red';
	wp_enqueue_style( 'elead-pro-color', get_template_directory_uri() . '/assets/css/'. $theme_color .$min.'.css', array(), '' );

	// Load the html5 shiv.
	wp_enqueue_script( 'elead-pro-html5', get_template_directory_uri() . '/assets/js/html5' .$min. '.js', array(), '3.7.3' );
	wp_script_add_data( 'elead-pro-html5', 'conditional', 'lt IE 9' );

	wp_enqueue_script( 'elead-pro-skip-link-focus-fix', get_template_directory_uri() . '/assets/js/skip-link-focus-fix' .$min. '.js', array(), '20160412', true );

	wp_enqueue_script( 'elead-pro-navigation', get_template_directory_uri() . '/assets/js/navigation' .$min. '.js', array(), '20151215', true );

	wp_enqueue_script( 'jquery-slick', get_template_directory_uri() . '/assets/plugins/js/slick' .$min. '.js', array('jquery'), '1.6.0', true );
	
	wp_enqueue_script( 'jquery-parallax', get_template_directory_uri() . '/assets/plugins/js/jquery.parallax' .$min. '.js', array('jquery'), '0.6.2', true );
	
	// jquery isotope pkgd
	wp_enqueue_script( 'jquery-isotope-pkgd', get_template_directory_uri() . '/assets/plugins/js/isotope-pkgd' .$min. '.js', array( 'jquery' ), '3.0.4', true );

	wp_enqueue_script( 'packery-mode', get_template_directory_uri() . '/assets/plugins/js/packery-mode.pkgd' .$min. '.js', array('jquery'), '2.0.0', true );
	
	wp_enqueue_script( 'jquery-magnific-popup', get_template_directory_uri() . '/assets/plugins/js/jquery.magnific-popup' .$min. '.js', array('jquery'), '1.1.0', true );

	wp_enqueue_script( 'elead-pro-custom', get_template_directory_uri() . '/assets/js/custom' .$min. '.js', array('jquery'), '', true );

	if ( 'infinite' == $options['pagination_type'] ) {
		// infinite scroll js
		wp_enqueue_script( 'elead-pro-infinite-scroll', get_template_directory_uri() . '/assets/js/infinite-scroll' . $min . '.js', array( 'jquery' ), '', true );
	}

	if ( is_singular() && comments_open() && get_option( 'thread_comments' ) ) {
		wp_enqueue_script( 'comment-reply' );
	}
}
add_action( 'wp_enqueue_scripts', 'elead_pro_scripts' );

/**
 * Enqueue editor styles for Gutenberg
 *
 * @since Elead Pro 1.0.0
 */
function elead_pro_block_editor_styles() {
	$min = defined( 'SCRIPT_DEBUG' ) && SCRIPT_DEBUG ? '' : '.min';
	// Block styles.
	wp_enqueue_style( 'elead-pro-block-editor-style', get_theme_file_uri( '/assets/css/editor-blocks' .$min. '.css', array(), '' ));
	// Add custom fonts.
	wp_enqueue_style( 'elead-pro-fonts', elead_pro_fonts_url(), array(), null );
}
add_action( 'enqueue_block_editor_assets', 'elead_pro_block_editor_styles' );

/**
 * Implement the Custom Header feature.
 */
require get_template_directory() . '/inc/custom-header.php';

/**
 * Custom template tags for this theme.
 */
require get_template_directory() . '/inc/template-tags.php';

/**
 * Custom functions that act independently of the theme templates.
 */
require get_template_directory() . '/inc/extras.php';

/**
 * Load Jetpack compatibility file.
 */
require get_template_directory() . '/inc/jetpack.php';

/**
 * Load core file
 */
require get_template_directory() . '/inc/core.php';
