<?php
/**
 * Slider Section options
 *
 * @package Theme Palace
 * @subpackage Elead Pro
 * @since Elead Pro 1.0
 */

$wp_customize->add_section( 'elead_pro_slider', array(
	'title'             => esc_html__( 'Slider','elead-pro' ),
	'description'       => esc_html__( 'Slider Section Options.', 'elead-pro' ),
	'panel'             => 'elead_pro_sections_panel',
) );

// Slider Section enable setting and control.
$wp_customize->add_setting( 'elead_pro_theme_options[slider_enable]', array(
	'sanitize_callback'	=> 'elead_pro_sanitize_checkbox',
	'default'          	=> $options['slider_enable'],
) );

$wp_customize->add_control( 'elead_pro_theme_options[slider_enable]', array(
	'label'            	=> esc_html__( 'Enable Slider Section', 'elead-pro' ),
	'section'          	=> 'elead_pro_slider',
	'type'             	=> 'checkbox',
) );

// Slider effect setting and control.
$wp_customize->add_setting( 'elead_pro_theme_options[slider_effect]', array(
	'default'          	=> $options['slider_effect'],
	'sanitize_callback'	=> 'elead_pro_sanitize_select',
) );

$wp_customize->add_control( 'elead_pro_theme_options[slider_effect]', array(
	'label'            	=> esc_html__( 'Transition Effect', 'elead-pro' ),
	'section'          	=> 'elead_pro_slider',
	'type'             	=> 'select',
	'active_callback'	=> 'elead_pro_is_slider_enable',
	'choices'			=> elead_pro_slider_effect(),
) );

// Add slider transition duration setting and control.
$wp_customize->add_setting( 'elead_pro_theme_options[slider_transition_duration]', array(
	'default'           => $options['slider_transition_duration'],
	'sanitize_callback' => 'elead_pro_sanitize_select'
) );

$wp_customize->add_control( 'elead_pro_theme_options[slider_transition_duration]', array(
	'label'           	=> esc_html__( 'Transition Duration', 'elead-pro' ),
	'section'         	=> 'elead_pro_slider',
	'type'            	=> 'select',
	'active_callback' 	=> 'elead_pro_is_slider_enable',
	'choices'         	=> elead_pro_slider_transition_duration(),
) );

// Add enable arrow controls setting and control.
$wp_customize->add_setting( 'elead_pro_theme_options[enable_slider_controls]', array(
	'default'           => $options['enable_slider_controls'],
	'sanitize_callback' => 'elead_pro_sanitize_checkbox'
) );

$wp_customize->add_control( 'elead_pro_theme_options[enable_slider_controls]', array(
	'label'           	=> esc_html__( 'Enable Arrow Controls', 'elead-pro' ),
	'section'         	=> 'elead_pro_slider',
	'type'            	=> 'checkbox',
	'active_callback' 	=> 'elead_pro_is_slider_enable',
) );

// Add enable slider pager setting and control.
$wp_customize->add_setting( 'elead_pro_theme_options[enable_slider_pager]', array(
	'default'           => $options['enable_slider_pager'],
	'sanitize_callback' => 'elead_pro_sanitize_checkbox'
) );

$wp_customize->add_control( 'elead_pro_theme_options[enable_slider_pager]', array(
	'label'           	=> esc_html__( 'Enable Pager Controls', 'elead-pro' ),
	'section'         	=> 'elead_pro_slider',
	'type'            	=> 'checkbox',
	'active_callback' 	=> 'elead_pro_is_slider_enable',
) );

// Add enable slider dragable setting and control.
$wp_customize->add_setting( 'elead_pro_theme_options[enable_slider_dragable]', array(
	'default'           => $options['enable_slider_dragable'],
	'sanitize_callback' => 'elead_pro_sanitize_checkbox'
) );

$wp_customize->add_control( 'elead_pro_theme_options[enable_slider_dragable]', array(
	'label'           	=> esc_html__( 'Slider Draggable', 'elead-pro' ),
	'section'         	=> 'elead_pro_slider',
	'type'            	=> 'checkbox',
	'active_callback' 	=> 'elead_pro_is_slider_enable',
) );

// Add enable slider pause on hover setting and control.
$wp_customize->add_setting( 'elead_pro_theme_options[slider_pause_on_hover]', array(
	'default'           => $options['slider_pause_on_hover'],
	'sanitize_callback' => 'elead_pro_sanitize_checkbox'
) );

$wp_customize->add_control( 'elead_pro_theme_options[slider_pause_on_hover]', array(
	'label'           	=> esc_html__( 'Pause On Hover', 'elead-pro' ),
	'section'         	=> 'elead_pro_slider',
	'type'            	=> 'checkbox',
	'active_callback' 	=> 'elead_pro_is_slider_enable',
) );

// Add enable infinite slider setting and control.
$wp_customize->add_setting( 'elead_pro_theme_options[enable_infinite_slider]', array(
	'default'           => $options['enable_infinite_slider'],
	'sanitize_callback' => 'elead_pro_sanitize_checkbox'
) );

$wp_customize->add_control( 'elead_pro_theme_options[enable_infinite_slider]', array(
	'label'           	=> esc_html__( 'Enable Infinite Slider', 'elead-pro' ),
	'section'         	=> 'elead_pro_slider',
	'type'            	=> 'checkbox',
	'active_callback' 	=> 'elead_pro_is_slider_enable',
) );

// Add enable slider auto play setting and control.
$wp_customize->add_setting( 'elead_pro_theme_options[slider_autoplay]', array(
	'default'           => $options['slider_autoplay'],
	'sanitize_callback' => 'elead_pro_sanitize_checkbox'
) );

$wp_customize->add_control( 'elead_pro_theme_options[slider_autoplay]', array(
	'label'           	=> esc_html__( 'Auto Play', 'elead-pro' ),
	'section'         	=> 'elead_pro_slider',
	'type'            	=> 'checkbox',
	'active_callback' 	=> 'elead_pro_is_slider_enable',
) );

// Slider post hr setting and control
$wp_customize->add_setting( 'elead_pro_theme_options[slider_hr]', array(
	'sanitize_callback' => 'sanitize_text_field'
) );

$wp_customize->add_control( new Elead_Pro_Customize_Horizontal_Line( $wp_customize, 'elead_pro_theme_options[slider_hr]',
	array(
		'section'         => 'elead_pro_slider',
		'active_callback' => 'elead_pro_is_slider_enable',
		'type'			  => 'hr'
) ) );

// Add slider content type setting and control.
$wp_customize->add_setting( 'elead_pro_theme_options[slider_content_type]', array(
	'default'           => $options['slider_content_type'],
	'sanitize_callback' => 'elead_pro_sanitize_select'
) );

$wp_customize->add_control( 'elead_pro_theme_options[slider_content_type]', array(
	'label'           	=> esc_html__( 'Content Type', 'elead-pro' ),
	'description'     	=> esc_html__( 'Recommended slider image size is 1920x1080 px', 'elead-pro' ),
	'section'         	=> 'elead_pro_slider',
	'type'            	=> 'select',
	'active_callback' 	=> 'elead_pro_is_slider_enable',
	'choices'         	=> elead_pro_common_content_type()
) );

// Add slider number setting and control.
$wp_customize->add_setting( 'elead_pro_theme_options[no_of_slider]', array(
	'default'           => $options['no_of_slider'],
	'sanitize_callback' => 'elead_pro_sanitize_number_range',
	'validate_callback' => 'elead_pro_validate_slider_count',
	'transport'			=> 'postMessage',
) );

$wp_customize->add_control( 'elead_pro_theme_options[no_of_slider]', array(
	'label'           	=> esc_html__( 'Number of slides', 'elead-pro' ),
	'description'       => esc_html__( 'Note: Min 1 & Max 10. Please input the valid number and save. Then refresh the page to see the change.', 'elead-pro' ),
	'section'         	=> 'elead_pro_slider',
	'type'            	=> 'number',
	'active_callback' 	=> 'elead_pro_slider_count',
	'input_attrs'     	=> array(
		'max' 	=> 10,
		'min' 	=> 1,
		'style' => 'width:100px'
	)
) );

// Slider Section content type post setting and control.
$wp_customize->add_setting( 'elead_pro_theme_options[slider_content_post]', array(
	'sanitize_callback' => 'elead_pro_sanitize_post_ids',
) );

$wp_customize->add_control( 'elead_pro_theme_options[slider_content_post]', array(
	'active_callback'	=> 'elead_pro_slider_content_post',
	'label'             => esc_html__( 'Input Post Ids', 'elead-pro' ),
	'description'       => esc_html__( 'Simply hover post title on dashboard to see the Post ID. Max no. of posts allowed is 10. ie: 11, 24, 34', 'elead-pro' ),
	'section'           => 'elead_pro_slider',
	'type'				=> 'text'
) );

// Slider Section content type category setting and control
$wp_customize->add_setting( 'elead_pro_theme_options[slider_content_category]', array(
	'sanitize_callback' => 'elead_pro_sanitize_single_category'
) );

$wp_customize->add_control( new Elead_Pro_Dropdown_Single_Category_Control( $wp_customize, 'elead_pro_theme_options[slider_content_category]', array(
	'label'           => esc_html__( 'Select Category', 'elead-pro' ),
	'description'     => esc_html__( 'Latest posts from selected category will be shown.', 'elead-pro' ),
	'section'         => 'elead_pro_slider',
	'type'			  => 'dropdown-category',
	'active_callback' => 'elead_pro_slider_content_category',
) ) );

// Slider Section page setting and control
for ( $i = 1; $i <= $options['no_of_slider']; $i++ ) {
	// Show page drop-down setting and control
	$wp_customize->add_setting( 'elead_pro_theme_options[slider_content_page_'.$i.']', array(
		'sanitize_callback' => 'elead_pro_sanitize_page'
	) );

	$wp_customize->add_control( 'elead_pro_theme_options[slider_content_page_'.$i.']', array(
		'label'           	=> sprintf( esc_html__( 'Select Page %d', 'elead-pro' ), $i ),
		'section'        	=> 'elead_pro_slider',
		'active_callback' 	=> 'elead_pro_slider_content_page',
		'type'				=> 'dropdown-pages'
	) );

	// Slider custom post hr setting and control
	$wp_customize->add_setting( 'elead_pro_theme_options[slider_custom_hr_line_'.$i.']', array(
		'sanitize_callback' => 'sanitize_text_field'
	) );

	$wp_customize->add_control( new Elead_Pro_Customize_Horizontal_Line( $wp_customize, 'elead_pro_theme_options[slider_custom_hr_line_'.$i.']',
		array(
			'section'         => 'elead_pro_slider',
			'active_callback' => 'elead_pro_slider_content_custom',
			'type'			  => 'hr'
	) ) );

	// Slider custom note
	$wp_customize->add_setting( 'elead_pro_theme_options[slider_custom_note_'.$i.']', array(
		'sanitize_callback'	=> 'sanitize_text_field',
	) );

	$wp_customize->add_control( new Elead_Pro_Note_Control( $wp_customize, 'elead_pro_theme_options[slider_custom_note_'.$i.']', array(
		'label'           	=> sprintf( esc_html__( 'Input Custom Value For Slider %s ', 'elead-pro' ),$i ),
		'section'         	=> 'elead_pro_slider',
		'type'            	=> 'description',
		'active_callback' 	=> 'elead_pro_slider_content_custom',
	) ) );

	// Slider Section custom title setting and control.
	$wp_customize->add_setting( 'elead_pro_theme_options[slider_custom_title_'.$i.']', array(
		'sanitize_callback' => 'sanitize_text_field',
		'default'			=> esc_html__( 'Education Career','elead-pro' ),
	) );

	$wp_customize->add_control( 'elead_pro_theme_options[slider_custom_title_'.$i.']', array(
		'active_callback'	=> 'elead_pro_slider_content_custom',
		'label'             => sprintf( esc_html__( 'Custom Title %s', 'elead-pro' ),$i ),
		'section'           => 'elead_pro_slider',
		'type'				=> 'text'
	) );

	// Slider Section custom subtitle setting and control.
	$wp_customize->add_setting( 'elead_pro_theme_options[slider_custom_subtitle_'.$i.']', array(
		'sanitize_callback' => 'sanitize_text_field',
		'default'			=> esc_html__( 'Build Your','elead-pro' ),
	) );

	$wp_customize->add_control( 'elead_pro_theme_options[slider_custom_subtitle_'.$i.']', array(
		'active_callback'	=> 'elead_pro_is_demo_category_disable',
		'label'             => sprintf( esc_html__( 'Custom SubTitle %s', 'elead-pro' ),$i ),
		'section'           => 'elead_pro_slider',
		'type'				=> 'text'
	) );

	// Slider custom post hr setting and control
	$wp_customize->add_setting( 'elead_pro_theme_options[slider_custom_page_hr_line_'.$i.']', array(
		'sanitize_callback' => 'sanitize_text_field'
	) );

	$wp_customize->add_control( new Elead_Pro_Customize_Horizontal_Line( $wp_customize, 'elead_pro_theme_options[slider_custom_page_hr_line_'.$i.']',
		array(
			'section'         => 'elead_pro_slider',
			'active_callback' => 'elead_pro_slider_content_page',
			'type'			  => 'hr'
	) ) );

	// Slider Section custom excerpt setting and control.
	$wp_customize->add_setting( 'elead_pro_theme_options[slider_custom_excerpt_'.$i.']', array(
		'sanitize_callback' => 'wp_kses_post',
		'default'			=> esc_html__( 'Lorem ipsum dolor sit amet, consectetur adipiscing elit etiam eget augue quis elit tempor laoreet vestibulum purus quam, vestibulum sed malesuada id, hendrerit nec dolor.','elead-pro' ),
	) );

	$wp_customize->add_control( 'elead_pro_theme_options[slider_custom_excerpt_'.$i.']', array(
		'active_callback'	=> 'elead_pro_slider_content_custom',
		'label'             => sprintf( esc_html__( 'Custom Excerpt %s', 'elead-pro' ),$i ),
		'section'           => 'elead_pro_slider',
		'type'				=> 'textarea'
	) );

	// slider section custom background image setting and control.
	$wp_customize->add_setting( 'elead_pro_theme_options[slider_custom_image_'.$i.']', array(
		'sanitize_callback' => 'elead_pro_sanitize_image',
		'default'			=> get_template_directory_uri() . '/assets/uploads/main-slider.jpg',
	) );

	$wp_customize->add_control(
		new WP_Customize_Image_Control( $wp_customize, 'elead_pro_theme_options[slider_custom_image_'.$i.']',
			array(
			'label'       		=> sprintf( esc_html__( 'Custom Image %s', 'elead-pro' ),$i ),
			'description' 		=> sprintf( esc_html__( 'Recommended size: %1$dpx x %2$dpx ', 'elead-pro' ), 1920, 1080 ),
			'section'     		=> 'elead_pro_slider',
			'active_callback'	=> 'elead_pro_slider_content_custom',
	) ) );
	// Slider Section custom button label setting and control.
	$wp_customize->add_setting( 'elead_pro_theme_options[slider_custom_btn_label_'.$i.']', array(
		'sanitize_callback' => 'sanitize_text_field',
		'default'			=> esc_html__( 'Read More','elead-pro' ),
	) );

	$wp_customize->add_control( 'elead_pro_theme_options[slider_custom_btn_label_'.$i.']', array(
		'active_callback'	=> 'elead_pro_slider_content_custom',
		'label'             => sprintf( esc_html__( 'Custom button label %s', 'elead-pro' ),$i ),
		'section'           => 'elead_pro_slider',
		'type'				=> 'text'
	) );

	// Slider Section custom button url setting and control.
	$wp_customize->add_setting( 'elead_pro_theme_options[slider_custom_btn_url_'.$i.']', array(
		'sanitize_callback' => 'sanitize_text_field',
		'default'			=> esc_html__( '#','elead-pro' ),
	) );

	$wp_customize->add_control( 'elead_pro_theme_options[slider_custom_btn_url_'.$i.']', array(
		'active_callback'	=> 'elead_pro_slider_content_custom',
		'label'             => sprintf( esc_html__( 'Custom button url %s', 'elead-pro' ),$i ),
		'section'           => 'elead_pro_slider',
		'type'				=> 'text'
	) );

}

// Slider Section button label setting and control.
$wp_customize->add_setting( 'elead_pro_theme_options[slider_btn_label]', array(
	'default'           => $options['slider_btn_label'],
	'sanitize_callback' => 'sanitize_text_field',
) );

$wp_customize->add_control( 'elead_pro_theme_options[slider_btn_label]', array(
	'active_callback'	=> 'elead_pro_is_demo_custom_disable',
	'label'             => esc_html__( 'Input link button label', 'elead-pro' ),
	'section'           => 'elead_pro_slider',
	'type'				=> 'text'
) );
