<?php 
/**
 * Courses section
 *
 * This is the template for the content of courses section
 *
 * @package Theme Palace
 * @subpackage Elead Pro
 * @since Elead Pro 1.0
 */
if ( ! function_exists( 'elead_pro_add_courses_section' ) ) :
    /**
    * Add courses section
    *
    *@since Elead Pro 1.0
    */
    function elead_pro_add_courses_section() {
        $options = elead_pro_get_theme_options();

        // Check if courses is enabled
        $enable_courses = apply_filters( 'elead_pro_section_status', true, 'courses_enable' );

        if ( true !== $enable_courses ) {
            return false;
        }

        // Get courses section details
        $section_details = array();
        $section_details = apply_filters( 'elead_pro_filter_courses_section_details', $section_details );
        if ( empty( $section_details ) ) {
            return;
        }
        // Render courses section now.
        elead_pro_render_courses_section( $section_details );
    }
endif;
add_action( 'elead_pro_primary_content_action', 'elead_pro_add_courses_section', 40 );


if ( ! function_exists( 'elead_pro_get_courses_section_details' ) ) :
    /**
    * courses section details.
    *
    * @since Elead Pro 1.0
    * @param array $input courses section details.
    */
    function elead_pro_get_courses_section_details( $input ) {
        $options = elead_pro_get_theme_options();

        // courses type
        $courses_content_type  = $options['courses_content_type'];
        $no_of_courses = ! empty( $options['no_of_courses'] ) ? $options['no_of_courses'] : 3;

        $content = array();
        switch ( $courses_content_type ) {
          	case 'demo':
                $title = array (
                    1 => esc_html__( 'Painting & Sketch', 'elead-pro' ),
                    2 => esc_html__( 'Study Biology', 'elead-pro' ),
                    3 => esc_html__( 'Basic Photography', 'elead-pro' ),
                    );
                for ( $i = 1; $i <= 3; $i++ ) :
                    $content[$i]['img_array'][0] = get_template_directory_uri() . '/assets/uploads/courses-0' . $i . '.jpg';
                    $content[$i]['title']    = $title[$i];
                    $content[$i]['url']      = '#';
                    $content[$i]['excerpt']  = esc_html__( 'Interdum et malesuada fames ac ante ipsum primis in faucibus. Fusce male sua da ante sed rhoncus blandit...', 'elead-pro' );
                endfor;
            break;        

            case 'post':
                $ids = array();
                
                if ( ! empty( $options['courses_content_post'] ) )
                    $ids = ( array ) $options['courses_content_post'];

                // Bail if no valid pages are selected.
                if ( empty( $ids ) ) {
                    return $input;
                }

                $args = array(
                    'no_found_rows'  => true,
                    'orderby'        => 'post__in',
                    'post_type'      => 'post',
                    'post__in'       => $ids,
                    'posts_per_page' => 6,
                );  
                
          	break;

            case 'category':
                $cat_id = '';
                if ( ! empty( $options['courses_content_category'] ) ) {
                    $cat_id = $options['courses_content_category'];
                }

                // Bail if no valid pages are selected.
                if ( empty( $cat_id ) ) {
                    return $input;
                }else{
                    $cat_id = absint( $cat_id );
                }

                $args = array(
                    'no_found_rows'  => true,
                    'cat'            => $cat_id,
                    'post_type'      => 'post',
                    'posts_per_page' => absint( $no_of_courses ),
                );
            break;

            case 'course':
                $ids = array();
                
                if ( ! empty( $options['courses_content_course'] ) )
                    $ids = ( array ) $options['courses_content_course'];

                // Bail if no valid pages are selected.
                if ( empty( $ids ) ) {
                    return $input;
                }

                $args = array(
                    'no_found_rows'  => true,
                    'orderby'        => 'post__in',
                    'post_type'      => 'tp-course',
                    'post__in'       => $ids,
                    'posts_per_page' => 6,
                );  

            break;

            case 'course-category':
                $cat_id = '';
                if ( ! empty( $options['courses_content_course_category'] ) ) {
                    $cat_id = $options['courses_content_course_category'];
                }

                // Bail if no valid pages are selected.
                if ( empty( $cat_id ) ) {
                    return $input;
                }else{
                    $cat_id = absint( $cat_id );
                }

                $args = array(
                    'post_type'         => 'tp-course',
                    'posts_per_page'    => absint( $no_of_courses ),
                    'tax_query'         => array(
                        array(
                            'taxonomy'  => 'tp-course-category',
                            'field'     => 'id',
                            'terms'     => $cat_id
                        )
                    )
                );
                
            break;

            case 'custom':
                for ( $i = 1; $i <= absint( $no_of_courses ); $i++ ) :

                    $content[$i]['title'] = ! empty( $options['courses_custom_title_'.$i ] ) ? $options['courses_custom_title_'.$i] : esc_html__( 'Painting & Sketch', 'elead-pro' );       
                    $content[$i]['price'] = ! empty( $options['courses_custom_price_'.$i ] ) ? $options['courses_custom_price_'.$i] : esc_html__( '$300', 'elead-pro' );       
                    $content[$i]['excerpt'] = ! empty( $options['courses_custom_excerpt_'.$i ] ) ? $options['courses_custom_excerpt_'.$i] : esc_html__( 'Interdum et malesuada fames ac ante ipsum primis in faucibus. Fusce male sua da ante sed rhoncus blandit', 'elead-pro' );       
                    $content[$i]['img_array'][0] = ! empty( $options['courses_custom_image_'.$i ] ) ? $options['courses_custom_image_'.$i] : get_template_directory_uri() . '/assets/uploads/courses-01.jpg';
                    $content[$i]['url'] = ! empty( $options['courses_title_custom_url_'.$i ] ) ? $options['courses_title_custom_url_'.$i] : esc_html__( '#', 'elead-pro' );
                endfor;
            break;
            
        }

        if ( 'demo' != $courses_content_type && 'custom' != $courses_content_type ) {
            $posts = get_posts( $args );
            if ( ! empty( $posts ) ) :
                $i = 1;
                foreach ( $posts as $post ) :
                    $post_id = $post->ID;
                    $img_array = null;
                    if ( has_post_thumbnail( $post_id ) ) {
                        $img_array = wp_get_attachment_image_src( get_post_thumbnail_id( $post_id ), 'elead-pro-medium' );
                    } else {
                        $img_array[0] =  get_template_directory_uri().'/assets/uploads/no-featured-image-500x500.jpg';
                    }
                    if ( isset( $img_array ) ) {
                        $content[$i]['img_array'] = $img_array;
                    }

                    $content[$i]['id']       = $post_id;
                    $content[$i]['title']    = get_the_title( $post_id );
                    $content[$i]['url']      = get_the_permalink( $post_id );
                    $content[$i]['excerpt']  = elead_pro_trim_content( 15, $post );
                    $i++;
                endforeach;
            endif;
            wp_reset_postdata();
        }

        if ( ! empty( $content ) ) {
            $input = $content;
        }
        return $input;
    }
endif;
// courses section content details.
add_filter( 'elead_pro_filter_courses_section_details', 'elead_pro_get_courses_section_details' );


if ( ! function_exists( 'elead_pro_render_courses_section' ) ) :
    /**
    * Start courses section
    *
    * @return string courses content
    * @since Elead Pro 1.0
    *
    */
    function elead_pro_render_courses_section( $content_details ) {
        $options = elead_pro_get_theme_options();
        $title = ! empty( $options['courses_title'] ) ? $options['courses_title'] : '';
        $sub_title = ! empty( $options['courses_sub_title'] ) ? $options['courses_sub_title'] : '';
        $courses_content_type  = $options['courses_content_type'];

        $category_link  = '';
        $cat_name       = '';
        if ( $courses_content_type == 'category' ) {
            $category_link  = get_category_link( $options['courses_content_category'] );
            $cat_name       = get_the_category_by_ID( $options['courses_content_category'] );
        } elseif ( $courses_content_type == 'course-category' ) {
            $category_link  = get_term_link( $options['courses_content_course_category' ], 'tp-course-category' );
            $term           = get_term_by('id', $options['courses_content_course_category' ] , 'tp-course-category' );
            $cat_name       = $term->name;
        } elseif ( $courses_content_type == 'demo' ) {
            $category_link  = '#';
            $cat_name       = esc_html__( 'Courses', 'elead-pro' );
        } else {
            $category_link = ! empty( $options['courses_custom_btn_url'] ) ? $options['courses_custom_btn_url'] : '#';
            $cat_name      = ! empty( $options['courses_custom_btn_label'] ) ? $options['courses_custom_btn_label'] : '#';
        }
        $index = 1;
        if ( empty( $content_details ) ) {
            return;
        }
        ?>
            <section id="our-courses" class="page-section">
                <div class="wrapper">
                    <header class="entry-header align-center">
                        <?php if ( ! empty( $title ) ) : ?>
                            <h2 class="entry-title"><?php echo esc_html( $title ); ?></h2>
                        <?php endif; 
                        if ( ! empty( $sub_title ) ) : ?>
                            <p class="entry-title-desc"><?php echo esc_html( $sub_title ); ?></p>
                        <?php endif; ?>
                    </header>

                    <div class="entry-content col-3">
                        <?php foreach( $content_details as $content_detail ) : 
                            $addclass = '';
                            if ( 1 === $index || 4 === $index ) {
                                $addclass = '';
                                $addclass1 = 'right';
                            }
                            elseif ( 2 === $index || 5 === $index ) {
                                $addclass = 'course-style';
                                $addclass1 = 'center';
                            }
                            elseif ( 3 === $index || 6 === $index ) {
                                $addclass = '';
                                $addclass1 = 'left';
                            } ?>
                            <div class="hentry <?php echo esc_attr( $addclass ); ?>">
                                <div class="featured-course-wrapper">
                                    <?php if ( ! empty( $content_detail['img_array'][0] ) ) : ?>
                                        <a href="<?php echo esc_url( $content_detail['url'] ); ?>" 
                                            class="course-single-link">
                                            <div class="featured-image" style="background-image: url( '<?php echo esc_url( $content_detail['img_array'][0] ); ?>' )">
                                            </div>
                                        </a>
                                    <?php endif; ?>
                                    <div class="entry-container align-<?php echo esc_attr( $addclass1 ); ?>">
                                        <div class="entry-content">
                                            <?php if ( in_array( $courses_content_type , array( 'course', 'course-category' ) ) && has_action( 'tp_course_price_action' ) ) : 
                                                do_action( 'tp_course_price_action', absint( $content_detail['id'] ) );
                                            elseif ( 'demo' == $courses_content_type ) : ?>
                                                <span class="tp-course-price"><?php esc_html_e( '$545', 'elead-pro' ); ?></span>
                                            <?php elseif ( 'custom' == $courses_content_type  && ! empty( $content_detail['price'] ) ) : ?>
                                                <span class="tp-course-price"><?php echo  esc_html( $content_detail['price'] ); ?></span>
                                            <?php endif;
                                            if ( ! empty( $content_detail['title'] ) ) : ?>
                                                <h5 class="featured-title"><a href="<?php echo ! empty( $content_detail['url'] ) ? esc_url( $content_detail['url'] ) : '#'; ?>"><?php echo esc_html( $content_detail['title'] ); ?></a></h5>
                                            <?php endif;
                                            if ( ! empty( $content_detail['excerpt'] ) ) { ?>
                                                <p><?php echo esc_html( $content_detail['excerpt'] ); ?></p>
                                            <?php } ?>
                                        </div><!-- .entry-content -->
                                    </div><!-- .entry-container -->
                                </div><!-- .featured-course-wrapper -->
                            </div><!-- .hentry -->
                        <?php $index++; endforeach; ?>
                    </div><!-- .entry-content -->
                    <?php if ( ! empty( $category_link ) && ! in_array( $courses_content_type, array( 'custom', 'post', 'course' ) ) ) : ?>
                        <div class="view-more">
                            <a href="<?php echo esc_url( $category_link ); ?>" class="btn btn-transparent"><?php printf( '%s ' . esc_html( $cat_name ), esc_html__( 'View all', 'elead-pro' ) ); ?></a>
                        </div>
                    <?php 
                    else : ?>
                        <div class="view-more">
                            <a href="<?php echo esc_url( $category_link ); ?>" class="btn btn-transparent"><?php echo esc_html( $cat_name ); ?></a>
                        </div>
                    <?php 
                    endif; ?>
                </div><!-- .wrapper -->
                <div class="page-decoration">
                    <img src="<?php echo get_template_directory_uri() . '/assets/uploads/decoration.png'; ?>" alt="<?php esc_attr__( 'Decoration','elead-pro' ); ?>">
                </div><!-- .page-decoration -->
            </section><!-- #featured-courses -->
        <?php }
endif;
