<?php 
/**
 * Latest News section
 *
 * This is the template for the content of latest news section
 *
 * @package Theme Palace
 * @subpackage Elead Pro
 * @since Elead Pro 1.0
 */
if ( ! function_exists( 'elead_pro_add_latest_news_section' ) ) :
    /**
    * Add latest news section
    *
    *@since Elead Pro 1.0
    */
    function elead_pro_add_latest_news_section() {
        $options = elead_pro_get_theme_options();

        // Check if latest news is enabled
        $enable_latest_news = apply_filters( 'elead_pro_section_status', true, 'latest_news_enable' );

        if ( true !== $enable_latest_news ) {
            return false;
        }

        // Get latest news section details
        $section_details = array();
        $section_details = apply_filters( 'elead_pro_filter_latest_news_section_details', $section_details );
        if ( empty( $section_details ) ) {
            return;
        }
        // Render latest news section now.
        elead_pro_render_latest_news_section( $section_details );
    }
endif;
add_action( 'elead_pro_primary_content_action', 'elead_pro_add_latest_news_section', 60 );


if ( ! function_exists( 'elead_pro_get_latest_news_section_details' ) ) :
    /**
    * latest news section details.
    *
    * @since Elead Pro 1.0
    * @param array $input latest news section details.
    */
    function elead_pro_get_latest_news_section_details( $input ) {
        $options = elead_pro_get_theme_options();

        // latest news type
        $latest_news_content_type  = $options['latest_news_content_type'];

        $content = array();
        switch ( $latest_news_content_type ) {
          	case 'demo':
                $title = array(
                    esc_html__( 'College Spirits: Brings Festive Joy', 'elead-pro' ),
                    esc_html__( 'Sweet Charity - The Annual Musical Function', 'elead-pro' ),
                    esc_html__( 'Graduation Ceremony For This Fall', 'elead-pro' ),
                    esc_html__( 'The World Famous Ludlow Food Festival', 'elead-pro' ),
                    );
                for ( $i = 0; $i <= 3; $i++ ) :
                    $content[$i]['date']     = esc_html__( '2 DEC 2017', 'elead-pro' );
                    $content[$i]['title']    = $title[$i];
                    $content[$i]['url']      = '#';
                endfor;
                $content[0]['excerpt']  = esc_html__( 'lorem ipsum dolor sit amet, consectetur adipiscing elit. Proin efficitur gravida urna, quis rutrum mauris consectetur ac. Sed fringilla massa dignissim, pellentesque magna eget, pulvinar tortor.', 'elead-pro' );
                $content[0]['img_array'][0] = get_template_directory_uri() . '/assets/uploads/news-01.jpg';
            break;        

            case 'category':
                $cat_id = '';
                if ( ! empty( $options['latest_news_content_category'] ) ) {
                    $cat_id = $options['latest_news_content_category'];
                }

                // Bail if no valid pages are selected.
                if ( empty( $cat_id ) ) {
                    return $input;
                }else{
                    $cat_id = absint( $cat_id );
                }

                $args = array(
                    'no_found_rows'  => true,
                    'cat'            => $cat_id,
                    'post_type'      => 'post',
                    'posts_per_page' => 4,
                );
                                            
          	break;

            case 'event-category':
                $cat_id = '';
                if ( ! empty( $options['latest_news_content_event_category'] ) ) {
                    $cat_id = $options['latest_news_content_event_category'];
                }

                // Bail if no valid pages are selected.
                if ( empty( $cat_id ) ) {
                    return $input;
                }else{
                    $cat_id = absint( $cat_id );
                }

                $args = array(
                    'post_type'         => 'tp-event',
                    'posts_per_page'    => 4,
                    'tax_query'         => array(
                        array(
                            'taxonomy'  => 'tp-event-category',
                            'field'     => 'id',
                            'terms'     => $cat_id
                        )
                    )
                );
                                            
            break;

            case 'recent-event':
                $args = array(
                    'no_found_rows'  => true,
                    'post_type'      => 'tp-event',
                    'posts_per_page' => 4,
                );
                                            
            break;

            case 'recent-post':
                $args = array(
                    'no_found_rows'  => true,
                    'post_type'      => 'post',
                    'posts_per_page' => 4,
                );
                                            
            break;

        }

        if ( 'demo' != $latest_news_content_type ) {
            $posts = get_posts( $args );
            if ( ! empty( $posts ) ) :
                $i = 1;
                foreach ( $posts as $post ) :
                    $post_id = $post->ID;
                    $img_array = null;
                    if ( has_post_thumbnail( $post_id ) ) {
                        $img_array = wp_get_attachment_image_src( get_post_thumbnail_id( $post_id ), 'elead-pro-latest-news' );
                    } else {
                        $img_array[0] =  get_template_directory_uri() . '/assets/uploads/no-featured-image-650x310.jpg';
                    }

                    if ( isset( $img_array ) ) {
                        $content[$i]['img_array'] = $img_array;
                    }
                    $content[$i]['date']    = get_the_date( '', $post_id );
                    $content[$i]['title']   = get_the_title( $post_id );
                    $content[$i]['url']     = get_the_permalink( $post_id );
                    $content[$i]['excerpt'] = elead_pro_trim_content( 35, $post  );
                    $i++;
                endforeach;
            endif;
            wp_reset_postdata();
        }

        if ( ! empty( $content ) ) {
            $input = $content;
        }
        return $input;
    }
endif;
// latest news section content details.
add_filter( 'elead_pro_filter_latest_news_section_details', 'elead_pro_get_latest_news_section_details' );


if ( ! function_exists( 'elead_pro_render_latest_news_section' ) ) :
    /**
    * Start latest news section
    *
    * @return string latest news content
    * @since Elead Pro 1.0
    *
    */
    function elead_pro_render_latest_news_section( $content_details ) {
        $options = elead_pro_get_theme_options();
        $latest_news_content_type  = $options['latest_news_content_type'];
        $title = ! empty( $options['latest_news_title'] ) ? $options['latest_news_title'] : '';
        $sub_title = ! empty( $options['latest_news_subtitle'] ) ? $options['latest_news_subtitle'] : '';
        $readmore   = ! empty( $options['read_more_text'] ) ? $options['read_more_text'] : esc_html__( 'Read More', 'elead-pro' );
        $btn_label = ! empty( $options['latest_news_custom_btn_label']   ) ? $options['latest_news_custom_btn_label']   : '';
        $btn_url = ! empty( $options['latest_news_custom_btn_url']   ) ? $options['latest_news_custom_btn_url']   : '#';
        $index = 1;

        $category_link  = '';
        $cat_name       = '';
        if ( $latest_news_content_type == 'category' ) {
            $category_link  = get_category_link( $options['latest_news_content_category'] );
            $cat_name       = get_the_category_by_ID( $options['latest_news_content_category'] );
        } elseif ( $latest_news_content_type == 'event-category' ) {
            $category_link  = get_term_link( $options['latest_news_content_event_category' ], 'tp-event-category' );
            $term           = get_term_by('id', $options['latest_news_content_event_category' ] , 'tp-event-category' );
            $cat_name       = $term->name;
        } elseif ( $latest_news_content_type == 'demo' ) {
            $category_link  = '#';
            $cat_name       = esc_html__( 'News & Events', 'elead-pro' );
        }

        if ( empty( $content_details ) ) {
            return;
        }
        ?>
        <section id="news-events" class="bg-image" style="background-image:url('<?php echo get_template_directory_uri() . '/assets/uploads/bg-image.jpg'; ?>')">
            <div class="wrapper page-section">
                <div class="page-header align-center">
                    <?php if ( ! empty( $title ) ) : ?>
                        <h2><?php echo esc_html( $title ); ?></h2>
                    <?php endif; 
                    if ( ! empty( $sub_title ) ) : ?>
                        <h3><?php echo esc_html( $sub_title ); ?></h3>
                    <?php endif; ?>
                </div><!-- .page-header -->

                <div class="latest-archive blog-wrapper clear col-2">
                    <?php foreach ( $content_details as $content_detail ) : ?>
                        <div class="hentry">
                            <article>
                                <?php if ( ! empty( $content_detail['img_array'][0] ) ) : ?>
                                    <div class="featured-image">
                                        <img src="<?php echo esc_url( $content_detail['img_array'][0] ); ?>">
                                    </div><!-- .featured-image -->
                                <?php endif; ?>
                                <div class="news-content">
                                    <?php if ( ! empty( $content_detail['date'] ) ) : ?>
                                        <a href="<?php echo esc_url( $content_detail['url'] ); ?>" class="time">
                                            <time><?php echo esc_html( $content_detail['date'] ); ?></time>
                                        </a>
                                    <?php endif;
                                    if ( ! empty( $content_detail['title'] ) ) : ?> 
                                        <header class="entry-header">
                                            <h2 class="entry-title"><a href="<?php echo esc_url( $content_detail['url'] ); ?>"><?php echo esc_html( $content_detail['title'] ); ?></a></h2>
                                        </header><!-- .entry-header -->
                                    <?php endif;
                                    if ( ! empty( $content_detail['excerpt'] ) ) : ?>
                                        <div class="entry-content">
                                            <p><?php echo esc_html( $content_detail['excerpt'] ); ?></p>
                                        </div><!-- .entry-content -->
                                    <?php endif;
                                    if ( ! empty( $readmore ) ) : ?> 
                                        <a href="<?php echo esc_url( $content_detail['url'] ); ?>" class="read-more"><?php echo esc_html( $readmore ); ?></a>
                                    <?php endif; ?>
                                </div><!-- .news-content -->

                                <img src="<?php echo get_template_directory_uri() . '/assets/uploads/bgimage.png'; ?>" class="bg-news">
                            </article><!-- #post-1 -->
                        </div><!-- .hentry-->
                    <?php break;
                    endforeach;
                    array_shift( $content_details ); 
                    if ( ! empty( $content_details ) ) : ?>
                    <div class="hentry">
                        <div class="events clear">
                            <ul>
                                <?php foreach ( $content_details as $content_detail ) : ?>
                                    <li>
                                    <?php if ( ! empty( $content_detail['date'] ) ) : ?>
                                        <a href="<?php echo esc_url( $content_detail['url'] ); ?>" class="time">
                                            <time><?php echo esc_html( $content_detail['date'] ); ?></time>
                                        </a>
                                    <?php endif;
                                    if ( ! empty( $content_detail['title'] ) ) : ?> 
                                        <h5><a href="<?php echo esc_url( $content_detail['url'] ); ?>"><?php echo esc_html( $content_detail['title'] ); ?></a></h5>
                                    <?php endif;
                                    if ( ! empty( $readmore ) ) : ?>
                                        <a href="<?php echo esc_url( $content_detail['url'] ); ?>" class="read-more"><?php echo esc_html( $readmore ); ?></a>
                                    <?php endif; ?>
                                    </li>
                                <?php endforeach; ?>
                            </ul>
                        </div><!-- .events -->
                    </div><!-- .hentry -->
                    <?php endif; ?>
                </div><!-- .archive -->
                <?php if ( in_array( $latest_news_content_type, array( 'recent-post', 'recent-event' ) ) ) :    
                    if ( ! empty( $btn_label ) ) : ?>
                        <div class="align-center">
                            <a href="<?php echo esc_url( $btn_url ); ?>" class="btn btn-transparent"><?php echo esc_html( $btn_label ); ?></a>
                        </div><!-- .align-center -->
                    <?php endif;
                else :
                    if ( ! empty( $category_link ) ) { ?>
                    <div class="align-center">
                        <a href="<?php echo esc_url( $category_link ); ?>" class="btn btn-transparent"><?php printf( '%s ' . esc_html( $cat_name ), esc_html__( 'View all', 'elead-pro' ) ); ?></a>
                    </div>  
                <?php  } endif; ?>
            </div><!-- .wrapper -->
        </section><!-- #latest-news -->
    <?php }
endif;