<?php 
/**
 * Service section
 *
 * This is the template for the content of service section
 *
 * @package Theme Palace
 * @subpackage Elead Pro
 * @since Elead Pro 1.0
 */
if ( ! function_exists( 'elead_pro_add_service_section' ) ) :
    /**
    * Add service section
    *
    *@since Elead Pro 1.0
    */
    function elead_pro_add_service_section() {
        $options = elead_pro_get_theme_options();

        // Check if service is enabled
        $enable_service = apply_filters( 'elead_pro_section_status', true, 'service_enable' );

        if ( true !== $enable_service ) {
            return false;
        }

        // Get service section details
        $section_details = array();
        $section_details = apply_filters( 'elead_pro_filter_service_section_details', $section_details );
        if ( empty( $section_details ) ) {
            return;
        }
        // Render service section now.
        elead_pro_render_service_section( $section_details );
    }
endif;
add_action( 'elead_pro_primary_content_action', 'elead_pro_add_service_section', 30 );


if ( ! function_exists( 'elead_pro_get_service_section_details' ) ) :
    /**
    * service section details.
    *
    * @since Elead Pro 1.0
    * @param array $input service section details.
    */
    function elead_pro_get_service_section_details( $input ) {
        $options = elead_pro_get_theme_options();

        // service type
        $service_content_type  = $options['service_content_type'];

        switch ( $service_content_type ) {
            case 'demo':
                $service_title = array(
                    esc_html__( 'Best Place', 'elead-pro' ),
                    esc_html__( 'Quality Education', 'elead-pro' ),
                    esc_html__( 'Easy Learning', 'elead-pro' ),
                    esc_html__( 'Qualified Teacher', 'elead-pro' ),
                    );
                $service_icon = array(
                    esc_attr__( 'fa-anchor', 'elead-pro' ),
                    esc_attr__( 'fa-tint', 'elead-pro' ),
                    esc_attr__( 'fa-bars', 'elead-pro' ),
                    esc_attr__( 'fa-bell', 'elead-pro' ),
                    );
                for ( $i = 0; $i <= 3; $i++ ) {
                    $content[$i]['title']   = $service_title[$i];
                    $content[$i]['icon']    = $service_icon[$i];
                    $content[$i]['url']     = '#';
                    $content[$i]['excerpt'] = esc_html__( 'Proin efficitur velit et cursus vulputate. Aenean ele mentum sodales libero vitae auctor. Pellentesque tellus nisl, porta eu feugiat et, eleifend ut mi. ', 'elead-pro' );
                }
            break; 

            case 'page':
                $ids = array();

                for ( $i = 1; $i <= 4; $i++ ) {
                    $id = null;
                    if ( isset( $options[ 'service_content_page_'.$i ] ) ) {
                        $id = $options[ 'service_content_page_'.$i ];
                    }
                    if ( ! empty( $id ) ) {
                        $ids[] = absint( $id );
                    }
                }

                // Bail if no valid pages are selected.
                if ( empty( $ids ) ) {
                    return $input;
                }

                $args = array(
                    'no_found_rows'  => true,
                    'orderby'        => 'post__in',
                    'post_type'      => 'page',
                    'post__in'       => $ids,
                    'posts_per_page' => 4,
                );
            break;

            case 'category':
                $cat_id = '';
                if ( ! empty( $options['service_content_category'] ) ) {
                    $cat_id = $options['service_content_category'];
                }

                // Bail if no valid pages are selected.
                if ( empty( $cat_id ) ) {
                    return $input;
                }else{
                    $cat_id = absint( $cat_id );
                }

                $args = array(
                    'no_found_rows'  => true,
                    'cat'            => $cat_id,
                    'post_type'      => 'post',
                    'posts_per_page' => 4,
                );
            break;

            case 'post':
                $ids = array();
                
                if ( ! empty( $options['service_content_post'] ) )
                    $ids = ( array ) $options['service_content_post'];

                // Bail if no valid pages are selected.
                if ( empty( $ids ) ) {
                    return $input;
                }

                $args = array(
                    'no_found_rows'  => true,
                    'orderby'        => 'post__in',
                    'post_type'      => 'post',
                    'post__in'       => $ids,
                    'posts_per_page' => 4,
                );                             
            break;

            case 'custom':
                for ( $i = 1; $i <= 4; $i++ ) :

                    $content[$i]['title'] = ! empty( $options['service_custom_title_'.$i ] ) ? $options['service_custom_title_'.$i] : esc_html__( 'Easy Learning','elead-pro' );       
                    $content[$i]['excerpt'] = ! empty( $options['service_custom_excerpt_'.$i ] ) ? $options['service_custom_excerpt_'.$i] : esc_html__( 'Proin efficitur velit et cursus vulputate aenean ele mentum sodales libero vitae auctor pellentesque tellus nisl, porta eu feugiat et, eleifend ut mi.','elead-pro' );
                    $content[$i]['url'] = ! empty( $options['service_custom_url_'.$i ] ) ? $options['service_custom_url_'.$i] : esc_html__( '#','elead-pro' );
                    $content[$i]['icon'] = ! empty( $options['service_custom_icon_'.$i ] ) ? $options['service_custom_icon_'.$i] : 'fa-bars';
                endfor;
            break;

        } 

        if ( 'demo' != $service_content_type && 'custom' != $service_content_type ) {
            $posts = get_posts( $args );
            if ( ! empty( $posts ) ) :
                $i = 0;
                foreach ( $posts as $post ) :
                    $post_id = $post->ID;
                    $icon = get_post_meta( $post_id, 'elead-pro-post-icon', true );
                    $content[$i]['title']   = get_the_title( $post_id );
                    $content[$i]['url']     = get_the_permalink( $post_id );
                    $content[$i]['excerpt'] = elead_pro_trim_content( 20, $post  );
                    $content[$i]['icon']    = ! empty( $icon ) ? $icon : 'fa-tint' ;
                    $i++;
                endforeach;
            endif;
            wp_reset_postdata();
        }

        if ( ! empty( $content ) ) {
            $input = $content;
        }
        return $input;
    }
endif;
// service section content details.
add_filter( 'elead_pro_filter_service_section_details', 'elead_pro_get_service_section_details' );


if ( ! function_exists( 'elead_pro_render_service_section' ) ) :
    /**
    * Start service section
    *
    * @return string service content
    * @since Elead Pro 1.0
    *
    */
    function elead_pro_render_service_section( $content_details ) {
        $options    = elead_pro_get_theme_options();
        $service_title      = ! empty( $options['service_section_title'] ) ? $options['service_section_title'] : '';
        $service_subtitle  = ! empty( $options['service_section_subtitle'] ) ? $options['service_section_subtitle'] : '';

        if ( empty( $content_details ) ) {
            return;
        } ?>
        <section id="services" class="page-section">
            <div class="wrapper">
                <?php if( ! empty( $service_title ) || ! empty( $service_subtitle ) ) : ?>
                    <header class="entry-header align-center">
                        <?php if ( ! empty( $service_title ) ) : ?>
                            <h2 class="entry-title"><?php echo esc_html( $service_title ); ?></h2>
                        <?php endif; 
                        if ( ! empty( $service_subtitle ) ) : ?>
                            <p class="entry-title-desc"><?php echo esc_html( $service_subtitle ); ?></p>
                        <?php endif; ?>
                    </header><!-- .entry-header -->
                <?php endif; ?>            
                <div class="entry-content col-2">
                    <div class="row">                
                        <?php foreach ( $content_details as $content_detail ) : ?>
                        <div class="hentry">
                            <div class="services-wrapper">
                                <?php if( ! empty( $content_detail['icon'] ) ) { ?>
                                <div class="services-icon">
                                    <i class="fa <?php echo esc_html( $content_detail['icon'] ); ?>"></i>
                                </div><!-- .services-icon -->
                                <?php } ?>
                            </div><!-- .services-wrapper -->
                            <div class="services-content">
                                <?php if ( ! empty( $content_detail['title'] ) ) : ?>
                                    <h5 class="featured-title"><a href="<?php echo ! empty( $content_detail['url'] ) ? esc_url( $content_detail['url'] ) : '#'; ?>"><?php echo esc_html( $content_detail['title'] ); ?></a></h5>
                                <?php endif;
                                if( ! empty( $content_detail['excerpt'] ) ) { ?>
                                    <p><?php echo esc_html( $content_detail['excerpt'] ); ?></p>
                                <?php } ?>
                            </div><!-- .services-wrapper -->
                        </div><!-- .hentry -->
                        <?php endforeach; ?>    
                    </div><!-- .row -->
                </div><!-- .entry-content -->
            </div><!-- .wrapper -->
        </section><!-- #featured-services -->
    <?php }
endif;
