<?php 
/**
 * Slider section
 *
 * This is the template for the content of slider section
 *
 * @package Theme Palace
 * @subpackage Elead Pro
 * @since Elead Pro 1.0
 */
if ( ! function_exists( 'elead_pro_add_slider_section' ) ) :
    /**
    * Add slider section
    *
    *@since Elead Pro 1.0
    */
    function elead_pro_add_slider_section() {
        $options = elead_pro_get_theme_options();

        // Check if slider is enabled
        $enable_slider = apply_filters( 'elead_pro_section_status', true, 'slider_enable' );

        if ( true !== $enable_slider ) {
            return false;
        }

        // Get slider section details
        $section_details = array();
        $section_details = apply_filters( 'elead_pro_filter_slider_section_details', $section_details );
        if ( empty( $section_details ) ) {
            return;
        }
        // Render slider section now.
        elead_pro_render_slider_section( $section_details );
    }
endif;
add_action( 'elead_pro_primary_content_action', 'elead_pro_add_slider_section', 10 );


if ( ! function_exists( 'elead_pro_get_slider_section_details' ) ) :
    /**
    * slider section details.
    *
    * @since Elead Pro 1.0
    * @param array $input slider section details.
    */
    function elead_pro_get_slider_section_details( $input ) {
        $options = elead_pro_get_theme_options();

        // slider type
        $slider_content_type  = $options['slider_content_type'];

        $content = array();
        switch ( $slider_content_type ) {
          	case 'demo':
                for ( $i = 1; $i <= 2; $i++ ) :
                    $content[$i]['title']   = esc_html__( 'Education Career','elead-pro' );
                    $content[$i]['subtitle']= esc_html__( 'Build Your','elead-pro' );
                    $content[$i]['excerpt'] = esc_html__( 'This Perspective was produced as part of a commitment by to develop and share information, ideas and insights about how school leadership can contribute to improved student learning','elead-pro' );
                    $content[$i]['url']     = '#';
                    $content[$i]['btn_label'] = esc_html__( 'Read More','elead-pro' );
                    $content[$i]['img_array'][0] = get_template_directory_uri() . '/assets/uploads/main-slider.jpg';
                endfor;
            break;        

          	case 'page':
                $ids = array();

                for ( $i = 1; $i <= $options['no_of_slider']; $i++ ) {
                    $id = null;
                    if ( isset( $options[ 'slider_content_page_'.$i ] ) ) {
                        $id = $options[ 'slider_content_page_'.$i ];
                    }
                    if ( ! empty( $id ) ) {
                        $ids[] = absint( $id );
                    }
                }

                // Bail if no valid pages are selected.
                if ( empty( $ids ) ) {
                    return $input;
                }

                $args = array(
                    'no_found_rows'  => true,
                    'orderby'        => 'post__in',
                    'post_type'      => 'page',
                    'post__in'       => $ids,
                    'posts_per_page'  => absint( $options['no_of_slider'] ),
                );
            break;

            case 'category':
                $cat_id = '';
                if ( ! empty( $options['slider_content_category'] ) ) {
                    $cat_id = $options['slider_content_category'];
                }

                // Bail if no valid pages are selected.
                if ( empty( $cat_id ) ) {
                    return $input;
                }else{
                    $cat_id = absint( $cat_id );
                }

                $args = array(
                    'no_found_rows'  => true,
                    'cat'            => $cat_id,
                    'post_type'      => 'post',
                    'posts_per_page'  => absint( $options['no_of_slider'] ),
                );
            break;

            case 'post':
                $ids = array();
                
                if ( ! empty( $options['slider_content_post'] ) )
                    $ids = ( array ) $options['slider_content_post'];

                // Bail if no valid pages are selected.
                if ( empty( $ids ) ) {
                    return $input;
                }

                $args = array(
                    'no_found_rows'  => true,
                    'orderby'        => 'post__in',
                    'post_type'      => 'post',
                    'post__in'       => $ids,
                    'posts_per_page'  => absint( $options['no_of_slider'] ),
                );                             
          	break;

            case 'custom':
                for ( $i = 1; $i <= $options['no_of_slider']; $i++ ) :

                    $content[$i]['title']       = ! empty( $options['slider_custom_title_'.$i ] ) ? $options['slider_custom_title_'.$i ] : esc_html__( 'Education Career','elead-pro' );        
                    $content[$i]['subtitle']    = ! empty( $options['slider_custom_subtitle_'.$i ] ) ? $options['slider_custom_subtitle_'.$i ] : esc_html__( 'Build Your','elead-pro' );        
                    $content[$i]['excerpt']     = ! empty( $options['slider_custom_excerpt_'.$i ] ) ? $options['slider_custom_excerpt_'.$i ] : esc_html__( 'Lorem ipsum dolor sit amet, consectetur adipiscing elit etiam eget augue quis elit tempor laoreet vestibulum purus quam, vestibulum sed malesuada id, hendrerit nec dolor','elead-pro' );        
                    $content[$i]['img_array'][0]   = ! empty( $options['slider_custom_image_'.$i ] ) ? $options['slider_custom_image_'.$i ] : get_template_directory_uri() . '/assets/uploads/main-slider.jpg';        
                    $content[$i]['btn_label']   = ! empty( $options['slider_custom_btn_label_'.$i ] ) ? $options['slider_custom_btn_label_'.$i ] : esc_html__( 'Read More','elead-pro' );        
                    $content[$i]['url']         = ! empty( $options['slider_custom_btn_url_'.$i ] ) ? $options['slider_custom_btn_url_'.$i ] : esc_html__( '#','elead-pro' );
                endfor;
            break;
        }

        if ( 'demo' != $slider_content_type && 'custom' != $slider_content_type ) {
            $posts = get_posts( $args );
            if ( ! empty( $posts ) ) :
                $i = 1;
                foreach ( $posts as $post ) :
                    $post_id = $post->ID;
                    $img_array = null;
                    if ( has_post_thumbnail( $post_id ) ) {
                        $img_array = wp_get_attachment_image_src( get_post_thumbnail_id( $post_id ), 'full' );
                    } else {
                        $img_array[0] =  get_template_directory_uri().'/assets/uploads/no-featured-image-1920x1080.jpg';
                    }

                    if ( isset( $img_array ) ) {
                        $content[$i]['img_array'] = $img_array;
                    }
                    $content[$i]['title']   = get_the_title( $post_id );
                    $content[$i]['url']     = get_the_permalink( $post_id );
                    $content[$i]['excerpt'] = elead_pro_trim_content( 20, $post  );

                    if( ! empty( $options['slider_btn_label' ] ) ) {
                        $content[$i]['btn_label'] = $options['slider_btn_label'];        
                    }
                    if ( 'category' != $slider_content_type ) {
                        $content[$i]['subtitle']    = ! empty( $options['slider_custom_subtitle_'.$i ] ) ? $options['slider_custom_subtitle_'.$i ] : '';
                    }
                    $i++;
                endforeach;
            endif;
            wp_reset_postdata();
        }

        if ( ! empty( $content ) ) {
            $input = $content;
        }
        return $input;
    }
endif;
// slider section content details.
add_filter( 'elead_pro_filter_slider_section_details', 'elead_pro_get_slider_section_details' );


if ( ! function_exists( 'elead_pro_render_slider_section' ) ) :
    /**
    * Start slider section
    *
    * @return string slider content
    * @since Elead Pro 1.0
    *
    */
    function elead_pro_render_slider_section( $content_details ) {
        $options = elead_pro_get_theme_options();
        $slider_effect    = ( $options['slider_effect'] == 'fade' ) ? 'linear' : $options['slider_effect'];
        $slider_fade      = ( $options['slider_effect'] == 'fade' ) ? 'true' : 'false';
        $slider_control   = ( $options['enable_slider_controls'] == true ) ? 'true' : 'false';
        $slider_pager     = ( $options['enable_slider_pager'] == true ) ? 'true' : 'false';
        $slider_dragable  = ( $options['enable_slider_dragable'] == true ) ? 'true' : 'false';
        $slider_infinite  = ( $options['enable_infinite_slider'] == true ) ? 'true' : 'false';
        $slider_pause     = ( $options['slider_pause_on_hover'] == true ) ? 'true' : 'false';
        $slider_autoplay  = ( $options['slider_autoplay'] == true ) ? 'true' : 'false';
        $slider_speed     = ( $options['slider_transition_duration'] ) ? $options['slider_transition_duration'] : 1000;

        if ( empty( $content_details ) ) {
            return;
        } ?>
        <section id="main-slider" data-effect="<?php echo esc_attr( $slider_effect ); ?>" data-slick='{"slidesToShow": 1, "slidesToScroll": 1, "infinite": <?php echo esc_attr( $slider_infinite ); ?>, "speed": <?php echo esc_attr( $slider_speed ); ?>, "dots": <?php echo esc_attr( $slider_pager ); ?>, "arrows":<?php echo esc_attr( $slider_control ); ?>, "autoplay": <?php echo esc_attr( $slider_autoplay ); ?>, "fade": <?php echo esc_attr( $slider_fade ); ?>, "draggable": <?php echo esc_attr( $slider_dragable ); ?>, "pauseOnHover": <?php echo esc_attr( $slider_pause ); ?> }'>
            
            <?php foreach ( $content_details as $content_detail ) : ?>
                <div class="slick-item" style="background-image:url('<?php echo esc_url( $content_detail['img_array'][0] ); ?>')">
                    <div class="wrapper">
                        <div class="main-slider-contents animated animatedFadeInUp">
                            <?php if ( ! empty( $content_detail['subtitle'] ) ) {
                                echo '<span>' . esc_html( $content_detail['subtitle'] ) . '</span>';
                            } 
                            if ( ! empty( $content_detail['title'] ) ) { ?>
                                <h2 class="page-title"><?php echo esc_html( $content_detail['title'] ); ?></h2>
                            <?php } 
                            if ( ! empty( $content_detail['excerpt'] ) ) {
                                echo '<p>' . esc_html( $content_detail['excerpt'] ) . '</p>';
                            }
                            if ( ! empty( $content_detail['btn_label'] ) ) { ?>
                                <a href="<?php echo ! empty( $content_detail['url'] ) ? esc_url( $content_detail['url'] ) : '#'; ?>" class="btn btn-fill"><?php echo esc_html( $content_detail['btn_label'] ); ?></a>
                           <?php } ?>
                        </div><!-- .slider-content -->
                    </div><!-- .wrapper -->
                </div><!-- .slick-item -->
            <?php endforeach; ?>
        </section><!-- #main-slider -->
    <?php }
endif;