<?php 
/**
 * Team section
 *
 * This is the template for the content of team section
 *
 * @package Theme Palace
 * @subpackage Elead Pro
 * @since Elead Pro 1.0
 */
if ( ! function_exists( 'elead_pro_add_team_section' ) ) :
    /**
    * Add team section
    *
    *@since Elead Pro 1.0
    */
    function elead_pro_add_team_section() {
        $options = elead_pro_get_theme_options();

        // Check if team is enabled
        $enable_team = apply_filters( 'elead_pro_section_status', true, 'team_enable' );

        if ( true !== $enable_team ) {
            return false;
        }

        // Get team section details
        $section_details = array();
        $section_details = apply_filters( 'elead_pro_filter_team_section_details', $section_details );
        if ( empty( $section_details ) ) {
            return;
        }
        // Render team section now.
        elead_pro_render_team_section( $section_details );
    }
endif;
add_action( 'elead_pro_primary_content_action', 'elead_pro_add_team_section', 70 );


if ( ! function_exists( 'elead_pro_get_team_section_details' ) ) :
    /**
    * team section details.
    *
    * @since Elead Pro 1.0
    * @param array $input team section details.
    */
    function elead_pro_get_team_section_details( $input ) {
        $options = elead_pro_get_theme_options();

        // team type
        $team_content_type  = $options['team_content_type'];

        switch ( $team_content_type ) {
            case 'demo':
                $team_title = array(
                    1 => esc_html__( 'Ricky Ortega', 'elead-pro' ),
                    2 => esc_html__( 'Anna Orcutt', 'elead-pro' ),
                    3 => esc_html__( 'Nick Hayan', 'elead-pro' ),
                    4 => esc_html__( 'Linda Anderson', 'elead-pro' ),
                    );
                for ( $i = 1; $i <= 4; $i++ ) {
                    $content[$i]['id']      = '';
                    $content[$i]['title']   = $team_title[$i];
                    $content[$i]['url']     = '#';
                    $content[$i]['img_array'][0]    = get_template_directory_uri() . '/assets/uploads/professional-0' . $i . '.jpg';
                    $content[$i]['img_array'][1]    = 400;
                    $content[$i]['img_array'][2]    = 400;
                }
            break; 

            case 'category':
                $cat_id = '';
                if ( ! empty( $options['team_content_category'] ) ) {
                    $cat_id = $options['team_content_category'];
                }

                // Bail if no valid pages are selected.
                if ( empty( $cat_id ) ) {
                    return $input;
                }else{
                    $cat_id = absint( $cat_id );
                }

                $args = array(
                    'no_found_rows'  => true,
                    'cat'            => $cat_id,
                    'post_type'      => 'post',
                    'posts_per_page' => 4,
                );
            break;

            case 'post':
                $ids = array();
                
                if ( ! empty( $options['team_content_post'] ) )
                    $ids = ( array ) $options['team_content_post'];

                // Bail if no valid pages are selected.
                if ( empty( $ids ) ) {
                    return $input;
                }

                $args = array(
                    'no_found_rows'  => true,
                    'orderby'        => 'post__in',
                    'post_type'      => 'post',
                    'post__in'       => $ids,
                    'posts_per_page' => 4,
                );                             
            break;

            case 'team':
                $ids = array();
                
                if ( ! empty( $options['team_content_team'] ) )
                    $ids = ( array ) $options['team_content_team'];

                // Bail if no valid pages are selected.
                if ( empty( $ids ) ) {
                    return $input;
                }

                $args = array(
                    'no_found_rows'  => true,
                    'orderby'        => 'post__in',
                    'post_type'      => 'tp-team',
                    'post__in'       => $ids,
                    'posts_per_page' => 4,
                );                             
            break;

            case 'team-category':
                $cat_id = '';
                if ( ! empty( $options['team_content_team_category'] ) ) {
                    $cat_id = $options['team_content_team_category'];
                }

                // Bail if no valid pages are selected.
                if ( empty( $cat_id ) ) {
                    return $input;
                }else{
                    $cat_id = absint( $cat_id );
                }

                $args = array(
                    'post_type'         => 'tp-team',
                    'posts_per_page'    => 4,
                    'tax_query'         => array(
                        array(
                            'taxonomy'  => 'tp-team-category',
                            'field'     => 'id',
                            'terms'     => $cat_id
                        )
                    )
                );
                
            break;

            case 'custom':
                for ( $i = 1; $i <= 4; $i++ ) :

                    $content[$i]['title'] = ! empty( $options['team_custom_title_'.$i ] ) ? $options['team_custom_title_'.$i] : esc_html__( 'Ricky Ortega','elead-pro' );        
                    $content[$i]['subtitle'] = ! empty( $options['team_custom_subtitle_'.$i ] ) ? $options['team_custom_subtitle_'.$i] : esc_html__( 'Art Teacher','elead-pro' );        
                    $content[$i]['img_array'][0] = ! empty( $options['team_custom_image_'.$i ] ) ? $options['team_custom_image_'.$i] : get_template_directory_uri() . '/assets/uploads/professional-01.jpg';
                    $content[$i]['img_array'][1] = 400;
                    $content[$i]['img_array'][2] = 400;        
                    $content[$i]['url'] = ! empty( $options['team_member_custom_url_'.$i ] ) ? $options['team_member_custom_url_'.$i] : esc_html__( '#','elead-pro' );        
                endfor;
            break;

        } 

        if ( 'demo' != $team_content_type && 'custom' != $team_content_type ) {
            $posts = get_posts( $args );
            if ( ! empty( $posts ) ) :
                $i = 1;
                foreach ( $posts as $post ) :
                    $post_id = $post->ID;
                    $img_array = array();
                    if ( has_post_thumbnail( $post_id ) ) {
                        $img_array = wp_get_attachment_image_src( get_post_thumbnail_id( $post_id ), 'elead-pro-medium' );
                    } else {
                        $img_array[0] =  get_template_directory_uri().'/assets/uploads/no-featured-image-500x500.jpg';
                        $img_array[1] =  400;
                        $img_array[2] =  400;
                    }

                    if ( isset( $img_array ) ) {
                        $content[$i]['img_array'] = $img_array;
                    }
                    $content[$i]['id']      = $post_id;
                    $content[$i]['title']   = get_the_title( $post_id );
                    $content[$i]['url']     = get_the_permalink( $post_id );
                    $i++;
                endforeach;
            endif;
            wp_reset_postdata();
        }

        if ( ! empty( $content ) ) {
            $input = $content;
        }
        return $input;
    }
endif;
// team section content details.
add_filter( 'elead_pro_filter_team_section_details', 'elead_pro_get_team_section_details' );


if ( ! function_exists( 'elead_pro_render_team_section' ) ) :
    /**
    * Start team section
    *
    * @return string team content
    * @since Elead Pro 1.0
    *
    */
    function elead_pro_render_team_section( $content_details ) {
        $options    = elead_pro_get_theme_options();
        $team_content_type  = $options['team_content_type'];
        $team_title      = ! empty( $options['team_section_title'] ) ? $options['team_section_title'] : '';
        $team_subtitle   = ! empty( $options['team_section_subtitle']  ) ? $options['team_section_subtitle']  : '';
        $team_excerpt    = ! empty( $options['team_section_excerpt']   ) ? $options['team_section_excerpt']   : '';
        $btn_label = ! empty( $options['team_custom_btn_label']   ) ? $options['team_custom_btn_label']   : '';
        $btn_url = ! empty( $options['team_custom_btn_url']   ) ? $options['team_custom_btn_url']   : '#';

        $category_link  = '';
        $cat_name       = '';
        if ( $team_content_type == 'category' ) {
            $category_link  = get_category_link( $options['team_content_category'] );
            $cat_name       = get_the_category_by_ID( $options['team_content_category'] );
        } elseif ( $team_content_type == 'team-category' ) {
            $category_link  = get_term_link( $options['team_content_team_category' ], 'tp-team-category' );
            $term           = get_term_by('id', $options['team_content_team_category' ] , 'tp-team-category' );
            $cat_name       = $term->name;
        } elseif ( $team_content_type == 'demo' ) {
            $category_link  = '#';
            $cat_name       = esc_html__( 'Teachers', 'elead-pro' );
        }

        if ( empty( $content_details ) ) {
            return;
        }
        ?>
        <section id="professional" class="page-section col-3">
            <div class="wrapper">
                <div class="row">
                    <div class="hentry">
                        <div class="professional-teacher align-left">
                            <header class="entry-header">
                                <?php if ( ! empty( $team_title ) ) : ?>
                                    <h2 class="entry-title"><?php echo esc_html( $team_title ); ?></h2>
                                <?php endif; 
                                if ( ! empty( $team_subtitle ) ) : ?>
                                    <p class="entry-title-desc"><?php echo esc_html( $team_subtitle ); ?></p>
                                <?php endif; ?>
                            </header>
                            <?php if ( ! empty( $team_excerpt ) ) : ?>
                                <div class="entry-content">
                                    <p><?php echo esc_html( $team_excerpt ); ?></p>
                                </div><!-- .entry-content -->
                            <?php endif; ?>
                        </div><!-- .professional-teacher -->
                    </div><!-- .hentry -->

                    <?php foreach ( $content_details as $content_detail ) : ?>
                        <div class="hentry">
                            <div class="professional-teacher">
                                <?php if( ! empty( $content_detail['img_array'][0] ) ) { ?>
                                    <a href="<?php echo ! empty( $content_detail['url'] ) ? esc_url( $content_detail['url'] ) : '#'; ?>"><img src="<?php echo esc_url( $content_detail['img_array'][0] ); ?>" width="<?php echo esc_attr( $content_detail['img_array'][1] ); ?>" height="<?php echo esc_attr( $content_detail['img_array'][2] ); ?>"></a>
                                <?php } ?>
                                <div class="hover-content">
                                    <?php if( ! empty( $content_detail['title'] ) ) { ?>
                                        <h5><a href="<?php echo ! empty( $content_detail['url'] ) ? esc_url( $content_detail['url'] ) : '#'; ?>"><?php echo esc_html( $content_detail['title'] ); ?></a></h5>
                                    <?php } ?>
                                    <?php if ( in_array( $team_content_type, array( 'team', 'team-category' ) ) ) : 
                                        if ( has_action( 'tp_team_designation_action' ) ) :
                                            do_action( 'tp_team_designation_action', $content_detail['id'] );
                                        endif;
                                    elseif ( $team_content_type == 'demo' ) : ?>
                                        <span class="tp-team-designation"><?php esc_html_e( 'Art Teacher', 'elead-pro' ); ?></span>
                                    <?php elseif ( $team_content_type == 'custom' && ! empty( $content_detail['subtitle'] ) ) : ?>
                                        <span class="tp-team-designation"><?php echo esc_html( $content_detail['subtitle'] ); ?></span>
                                    <?php endif; ?>
                                </div><!-- .hover-content -->
                            </div><!-- .professional-teacher -->
                        </div><!-- .hentry -->
                    <?php endforeach; ?>
                </div><!-- .row -->
                <?php if ( in_array( $team_content_type, array( 'team', 'custom', 'post' ) ) ) :    
                    if ( ! empty( $btn_label ) ) : ?>
                        <div class="align-center">
                            <a href="<?php echo esc_url( $btn_url ); ?>" class="btn btn-transparent"><?php echo esc_html( $btn_label ); ?></a>
                        </div><!-- .align-center -->
                    <?php endif;
                else :
                    if ( ! empty( $category_link ) ) { ?>
                    <div class="align-center">
                        <a href="<?php echo esc_url( $category_link ); ?>" class="btn btn-transparent"><?php printf( '%s ' . esc_html( $cat_name ), esc_html__( 'View all', 'elead-pro' ) ); ?></a>
                    </div>  
                <?php  } endif; ?>
            </div><!-- .wrapper -->
        </section><!-- #professional -->
    <?php }
endif;
