<?php 
/**
 * Testimonial section
 *
 * This is the template for the content of testimonial section
 *
 * @package Theme Palace
 * @subpackage Elead Pro
 * @since Elead Pro 1.0
 */
if ( ! function_exists( 'elead_pro_add_testimonial' ) ) :
    /**
    * Add testimonial section
    *
    *@since Elead Pro 1.0
    */
    function elead_pro_add_testimonial() {
        $options = elead_pro_get_theme_options();

        // Check if testimonial is enabled
        $enable_testimonial = apply_filters( 'elead_pro_section_status', true, 'testimonial_enable' );

        if ( true !== $enable_testimonial ) {
            return false;
        }

        // Get testimonial section details
        $section_details = array();
        $section_details = apply_filters( 'elead_pro_filter_testimonial_section_details', $section_details );
        if ( empty( $section_details ) ) {
            return;
        }
        // Render testimonial section now.
        elead_pro_render_testimonial_section( $section_details );
    }
endif;
add_action( 'elead_pro_add_testimonial_subscribe_hook', 'elead_pro_add_testimonial', 10 );


if ( ! function_exists( 'elead_pro_get_testimonial_section_details' ) ) :
    /**
    * testimonial section details.
    *
    * @since Elead Pro 1.0
    * @param array $input testimonial section details.
    */
    function elead_pro_get_testimonial_section_details( $input ) {
        $options = elead_pro_get_theme_options();

        // testimonial type
        $testimonial_content_type  = $options['testimonial_content_type'];
        $no_of_testimonial = ! empty( $options['no_of_testimonial'] ) ? $options['no_of_testimonial'] : 4;

        $content = array();
        switch ( $testimonial_content_type ) {
          	case 'demo':
                $title = array (
                    1 => esc_html__( 'Ricky Ortega', 'elead-pro' ),
                    2 => esc_html__( 'Peter Moraes', 'elead-pro' ),
                    3 => esc_html__( 'Milena Newman', 'elead-pro' ),
                    );
                for ( $i = 1; $i <= 3; $i++ ) :
                    $content[$i]['img_array'][0] = get_template_directory_uri() . '/assets/uploads/testimonial-0' . $i . '.jpg';
                    $content[$i]['img_array'][1] = 200;
                    $content[$i]['img_array'][2] = 200;
                    $content[$i]['id']       = '';
                    $content[$i]['title']    = $title[$i];
                    $content[$i]['url']      = '#';
                    $content[$i]['excerpt']  = esc_html__( 'Cras posuere, quam non pulvinar con sectetur, odio augue tempor tortor, in egestas felis odio eget leo. Suspendisse viverra orci urna.', 'elead-pro' );
                endfor;
            break;        

            case 'post':
                $ids = array();
                
                if ( ! empty( $options['testimonial_content_post'] ) )
                    $ids = ( array ) $options['testimonial_content_post'];

                // Bail if no valid pages are selected.
                if ( empty( $ids ) ) {
                    return $input;
                }

                $args = array(
                    'no_found_rows'  => true,
                    'orderby'        => 'post__in',
                    'post_type'      => 'post',
                    'post__in'       => $ids,
                    'posts_per_page' => absint( $no_of_testimonial ),
                );  
                
          	break;

            case 'category':
                $cat_id = '';
                if ( ! empty( $options['testimonial_content_category'] ) ) {
                    $cat_id = $options['testimonial_content_category'];
                }

                // Bail if no valid pages are selected.
                if ( empty( $cat_id ) ) {
                    return $input;
                }else{
                    $cat_id = absint( $cat_id );
                }

                $args = array(
                    'no_found_rows'  => true,
                    'cat'            => $cat_id,
                    'post_type'      => 'post',
                    'posts_per_page' => absint( $no_of_testimonial ),
                );
            break;

            case 'testimonial':
                $ids = array();
                
                if ( ! empty( $options['testimonial_content_testimonial'] ) )
                    $ids = ( array ) $options['testimonial_content_testimonial'];

                // Bail if no valid pages are selected.
                if ( empty( $ids ) ) {
                    return $input;
                }

                $args = array(
                    'no_found_rows'  => true,
                    'orderby'        => 'post__in',
                    'post_type'      => 'tp-testimonial',
                    'post__in'       => $ids,
                    'posts_per_page' => absint( $no_of_testimonial ),
                );
            break;

            case 'recent-testimonial':
                $args = array(
                    'post_type'      => 'tp-testimonial',
                    'posts_per_page' => absint( $no_of_testimonial ),
                );  
            break;

            case 'custom':
                for ( $i = 1; $i <= $no_of_testimonial; $i++ ) :

                    $content[$i]['title']       = ! empty( $options['testimonial_custom_title_'.$i ] ) ? $options['testimonial_custom_title_'.$i ] : esc_html__( 'Sia Ortega','elead-pro');        
                    $content[$i]['url']     = ! empty( $options['testimonial_custom_btn_url_'.$i ] ) ? $options['testimonial_custom_btn_url_'.$i ] : esc_html__( '#','elead-pro');
                    $content[$i]['designation']    = ! empty( $options['testimonial_custom_position_'.$i ] ) ? $options['testimonial_custom_position_'.$i ] : esc_html__( 'Ex Student','elead-pro');        
                    $content[$i]['excerpt']     = ! empty( $options['testimonial_custom_excerpt_'.$i ] ) ? $options['testimonial_custom_excerpt_'.$i ] : esc_html__( 'Suspendisse semper nulla et orci laoreet, eget sodales dui porttitor. Sed et laoreet lectus. Donec eget eros sit amet dui dignissim lobortis eu ut risus. Vivamus maximus neque nunc, sit amet sodales lectus tempus id','elead-pro');        
                    $content[$i]['img_array'][0]   = ! empty( $options['testimonial_custom_image_'.$i ] ) ? $options['testimonial_custom_image_'.$i ] : get_template_directory_uri() . '/assets/uploads/testimonial-02.jpg';        
                endfor;
            break;

            
        }

        if ( 'demo' != $testimonial_content_type && 'custom' != $testimonial_content_type ) {
            $posts = get_posts( $args );
            if ( ! empty( $posts ) ) :
                $i = 1;
                foreach ( $posts as $post ) :
                    $post_id = $post->ID;
                    $img_array = null;
                    if ( has_post_thumbnail( $post_id ) ) {
                        $img_array = wp_get_attachment_image_src( get_post_thumbnail_id( $post_id ), 'thumbnail' );
                    } else {
                        $img_array[0] =  get_template_directory_uri().'/assets/uploads/no-featured-image-150x150.jpg';
                        $img_array[1] =  500;
                        $img_array[2] =  500;
                    }
                    if ( isset( $img_array ) ) {
                        $content[$i]['img_array'] = $img_array;
                    }

                    $content[$i]['id']       = $post_id;
                    $content[$i]['title']    = get_the_title( $post_id );
                    $content[$i]['url']      = get_the_permalink( $post_id );
                    $content[$i]['excerpt']  = elead_pro_trim_content( 25, $post );
                    $i++;
                endforeach;
            endif;
            wp_reset_postdata();
        }

        if ( ! empty( $content ) ) {
            $input = $content;
        }
        return $input;
    }
endif;
// testimonial section content details.
add_filter( 'elead_pro_filter_testimonial_section_details', 'elead_pro_get_testimonial_section_details' );


if ( ! function_exists( 'elead_pro_render_testimonial_section' ) ) :
    /**
    * Start testimonial section
    *
    * @return string testimonial content
    * @since Elead Pro 1.0
    *
    */
    function elead_pro_render_testimonial_section( $content_details ) {
        $options = elead_pro_get_theme_options();
        $title = ! empty( $options['testimonial_title'] ) ? $options['testimonial_title'] : '';
        $sub_title = ! empty( $options['testimonial_sub_title'] ) ? $options['testimonial_sub_title'] : '';
        $testimonial_content_type  = $options['testimonial_content_type'];

        if ( empty( $content_details ) ) {
            return;
        }
        ?>
        <div class="hentry align-center">
            <header class="entry-header">
                <?php if ( ! empty( $title ) ) : ?>
                    <h2 class="entry-title"><?php echo esc_html( $title ); ?></h2>
                <?php endif; 
                if ( ! empty( $sub_title ) ) : ?>
                    <p class="entry-title-desc"><?php echo esc_html( $sub_title ); ?></p>
                <?php endif; ?>
            </header>

            <div class="entry-content">
                <div class="testimonial-slider" data-slick='{"slidesToShow": 1, "slidesToScroll": 1, "infinite": false, "speed": 600, "dots": true, "arrows":false, "autoplay": true, "fade": false }'>
                    <?php foreach ( $content_details as $content_detail ) : 
                        if ( ! empty( $content_detail['img_array'][0] ) ) : ?>
                        <div class="slider-item" data-thumb="<?php echo esc_url( $content_detail['img_array'][0] ); ?>">
                            <div class="thumb-contents-wrapper">
                                <div class="thumb-contents">
                                    <img src="<?php echo get_template_directory_uri() . '/assets/uploads/testimonial.png'; ?>">
                                    <?php if( ! empty( $content_detail['excerpt'] ) ) : ?>
                                        <p><?php echo esc_html( $content_detail['excerpt'] ); ?></p>
                                    <?php endif;?>
                                </div><!-- .thumb-contents -->

                                <div class="thumb-image">
                                    <a href="<?php echo ! empty( $content_detail['url'] ) ? esc_url( $content_detail['url'] ) : '#'; ?>"><img src="<?php echo esc_url( $content_detail['img_array'][0] ); ?>"></a>
                                    <?php if ( ! empty( $content_detail['title'] ) ) : ?>
                                        <h5><a href="<?php echo ! empty( $content_detail['url'] ) ? esc_url( $content_detail['url'] ) : '#'; ?>"><?php echo esc_html( $content_detail['title'] ); ?></a></h5>
                                    <?php endif;
                                    if ( in_array( $testimonial_content_type, array( 'testimonial', 'recent-testimonial' ) ) ) : 
                                        if ( has_action( 'tp_testimonial_designation_action' ) ) :
                                            do_action( 'tp_testimonial_designation_action', $content_detail['id'] );
                                        endif;
                                    elseif ( 'demo' == $testimonial_content_type ) : ?>
                                        <span class="tp-testimonial-designation"><?php esc_html_e( 'Ex Student', 'elead-pro' ); ?></span>
                                    <?php
                                    elseif ( 'custom' == $testimonial_content_type ) : ?>
                                        <span class="tp-testimonial-designation"><?php esc_html( $content_detail['designation'] ); ?></span>
                                    <?php endif; ?>
                                </div><!-- thumb-image -->
                            </div><!-- .thumb-contents-wrapper -->
                        </div><!-- .slider-item -->
                    <?php endif; endforeach; ?>
                </div><!-- .testominal-slider -->
            </div><!-- .entry-content -->
        </div><!-- .hentry -->
    <?php }
endif;
